ZigElementType

Enum ZigElementType 

pub enum ZigElementType {
Show 178 variants Root, Whitespace, Newline, Comment, DocComment, Error, Eof, Identifier, StringLiteral, CharLiteral, IntegerLiteral, FloatLiteral, BooleanLiteral, Literal, Const, Var, Fn, Struct, Union, Enum, Opaque, Type, Comptime, Inline, NoInline, Pub, Export, Extern, Packed, Align, CallConv, LinkSection, If, Else, Switch, While, For, Break, Continue, Return, Defer, ErrDefer, Unreachable, NoReturn, ErrorKeyword, Test, Async, Await, Suspend, Resume, Cancel, Undefined, Null, Volatile, AllowZero, NoAlias, And, Or, AnyFrame, AnyType, ThreadLocal, Bool, I8, I16, I32, I64, I128, Isize, U8, U16, U32, U64, U128, Usize, F16, F32, F64, F80, F128, CShort, CUshort, CInt, CUint, CLong, CUlong, CLongLong, CUlongLong, CLongDouble, CVoid, Void, ComptimeInt, ComptimeFloat, Plus, Minus, Star, Slash, Percent, StarStar, PlusPercent, MinusPercent, StarPercent, PlusPlus, MinusMinus, Ampersand, Pipe, Caret, Tilde, LessLess, GreaterGreater, Equal, NotEqual, Less, Greater, LessEqual, GreaterEqual, AndAnd, OrOr, Assign, PlusAssign, MinusAssign, StarAssign, SlashAssign, PercentAssign, AmpersandAssign, PipeAssign, CaretAssign, LessLessAssign, GreaterGreaterAssign, LeftParen, RightParen, LeftBrace, RightBrace, LeftBracket, RightBracket, Semicolon, Comma, Dot, DotDot, DotDotDot, DotQuestion, DotStar, Colon, Question, Exclamation, Arrow, FatArrow, OrElse, CatchKeyword, TryKeyword, AwaitKeyword, At, BuiltinIdentifier, StringStart, StringEnd, StringContent, InterpolationStart, InterpolationEnd, MultilineStringStart, MultilineStringEnd, MultilineStringContent, CompileDirective, Text, FnDeclaration, VarDeclaration, StructDeclaration, EnumDeclaration, UnionDeclaration, IfStatement, WhileStatement, ForStatement, ReturnStatement, Block, BinaryExpr, UnaryExpr, ContainerField, BreakStatement, ContinueStatement, DeferStatement,
}
Zig element types.

Variants



Root

Root element.



Whitespace

Whitespace characters.



Newline

Newline character.



Comment

Comment.



DocComment

Documentation comment.



Error

Error token.



Eof

End of file.



Identifier

Identifier.



StringLiteral

String literal.



CharLiteral

Character literal.



IntegerLiteral

Integer literal.



FloatLiteral

Floating-point literal.



BooleanLiteral

Boolean literal.



Literal

Generic literal.



Const

const keyword.



Var

var keyword.



Fn

fn keyword.



Struct

struct keyword.



Union

union keyword.



Enum

enum keyword.



Opaque

opaque keyword.



Type

type keyword.



Comptime

comptime keyword.



Inline

inline keyword.



NoInline

noinline keyword.



Pub

pub keyword.



Export

export keyword.



Extern

extern keyword.



Packed

packed keyword.



Align

align keyword.



CallConv

callconv keyword.

linksection keyword.



If

if keyword.



Else

else keyword.



Switch

switch keyword.



While

while keyword.



For

for keyword.



Break

break keyword.



Continue

continue keyword.



Return

return keyword.



Defer

defer keyword.



ErrDefer

errdefer keyword.



Unreachable

unreachable keyword.



NoReturn

noreturn keyword.



ErrorKeyword

error keyword.



Test

test keyword.



Async

async keyword.



Await

await keyword.



Suspend

suspend keyword.



Resume

resume keyword.



Cancel

cancel keyword.



Undefined

undefined keyword.



Null

null keyword.



Volatile

volatile keyword.



AllowZero

allowzero keyword.



NoAlias

noalias keyword.



And

and keyword.



Or

or keyword.



AnyFrame

anyframe keyword.



AnyType

anytype keyword.



ThreadLocal

threadlocal keyword.



Bool

bool type.



I8

i8 type.



I16

i16 type.



I32

i32 type.



I64

i64 type.



I128

i128 type.



Isize

isize type.



U8

u8 type.



U16

u16 type.



U32

u32 type.



U64

u64 type.



U128

u128 type.



Usize

usize type.



F16

f16 type.



F32

f32 type.



F64

f64 type.



F80

f80 type.



F128

f128 type.



CShort

c_short type.



CUshort

c_ushort type.



CInt

c_int type.



CUint

c_uint type.



CLong

c_long type.



CUlong

c_ulong type.



CLongLong

c_longlong type.



CUlongLong

c_ulonglong type.



CLongDouble

c_longdouble type.



CVoid

c_void type.



Void

void type.



ComptimeInt

comptime_int type.



ComptimeFloat

comptime_float type.



Plus

+ operator.



Minus

- operator.



Star

* operator.



Slash

/ operator.



Percent

% operator.



StarStar

** operator.



PlusPercent

+% operator.



MinusPercent

-% operator.



StarPercent

*% operator.



PlusPlus

++ operator.



MinusMinus

-- operator.



Ampersand

& operator.



Pipe

| operator.



Caret

^ operator.



Tilde

~ operator.



LessLess

<< operator.



GreaterGreater

>> operator.



Equal

== operator.



NotEqual

!= operator.



Less

< operator.



Greater

> operator.



LessEqual

<= operator.



GreaterEqual

>= operator.



AndAnd

and logical operator.



OrOr

or logical operator.



Assign

= operator.



PlusAssign

+= operator.



MinusAssign

-= operator.



StarAssign

*= operator.



SlashAssign

/= operator.



PercentAssign

%= operator.



AmpersandAssign

&= operator.



PipeAssign

|= operator.



CaretAssign

^= operator.



LessLessAssign

<<= operator.



GreaterGreaterAssign

>>= operator.



LeftParen

( symbol.



RightParen

) symbol.



LeftBrace

{ symbol.



RightBrace

} symbol.



LeftBracket

[ symbol.



RightBracket

] symbol.



Semicolon

; symbol.



Comma

, symbol.



Dot

. symbol.



DotDot

.. symbol.



DotDotDot

... symbol.



DotQuestion

.? operator.



DotStar

.* operator.



Colon

: symbol.



Question

? symbol.



Exclamation

! symbol.



Arrow

-> operator.



FatArrow

=> operator.



OrElse

orelse operator.



CatchKeyword

catch operator.



TryKeyword

try operator.



AwaitKeyword

await operator.



At

@ symbol.



BuiltinIdentifier

Built-in identifier.



StringStart

Start of a string literal.



StringEnd

End of a string literal.



StringContent

Content of a string literal.



InterpolationStart

Start of string interpolation.



InterpolationEnd

End of string interpolation.



MultilineStringStart

Start of a multiline string.



MultilineStringEnd

End of a multiline string.



MultilineStringContent

Content of a multiline string.



CompileDirective

Compile-time directive.



Text

Text content.



FnDeclaration

Function declaration.



VarDeclaration

Variable declaration.



StructDeclaration

Struct declaration.



EnumDeclaration

Enum declaration.



UnionDeclaration

Union declaration.



IfStatement

If statement.



WhileStatement

While statement.



ForStatement

For statement.



ReturnStatement

Return statement.



Block

Block of code.



BinaryExpr

Binary expression.



UnaryExpr

Unary expression.



ContainerField

Container field.



BreakStatement

Break statement.



ContinueStatement

Continue statement.



DeferStatement

Defer statement.